
clustergrammer2
=====================================

Version: |release|

A custom Jupyter widget library built using the widget-ts-cookiecutter library'


Quickstart
----------

To get started with clustergrammer2, install with pip::

    pip install clustergrammer2

or with conda::

    conda install clustergrammer2


Contents
--------

.. toctree::
   :maxdepth: 2
   :caption: Installation and usage

   installing
   introduction

.. toctree::
   :maxdepth: 1

   examples/index


.. toctree::
   :maxdepth: 2
   :caption: Development

   develop-install


.. links

.. _`Jupyter widgets`: https://jupyter.org/widgets.html

.. _`notebook`: https://jupyter-notebook.readthedocs.io/en/latest/
